nereid-wishlist
===============

.. image:: https://travis-ci.org/openlabs/nereid-wishlist.svg?branch=develop 
  :target: https://travis-ci.org/openlabs/nereid-wishlist
  :alt: Build Status
.. image:: https://pypip.in/download/openlabs_nereid_wishlist/badge.svg
    :target: https://pypi.python.org/pypi/openlabs_nereid_wishlist/
    :alt: Downloads
.. image:: https://pypip.in/version/openlabs_nereid_wishlist/badge.svg
    :target: https://pypi.python.org/pypi/openlabs_nereid_wishlist/
    :alt: Latest Version
.. image:: https://pypip.in/status/openlabs_nereid_wishlist/badge.svg 
    :target: https://pypi.python.org/pypi/openlabs_nereid_wishlist/
    :alt: Development Status

Authors and Contributors
------------------------

This module was built at `Openlabs <http://www.openlabs.co.in>`_. 

Professional Support
--------------------

This module is professionally supported by `Openlabs <http://www.openlabs.co.in>`_.
If you are looking for on-site teaching or consulting support, contact our
`sales <mailto:sales@openlabs.co.in>`_ and `support
<mailto:support@openlabs.co.in>`_ teams.
